//Code by: Jason Amri
//jasonamri.com
//LCD Inverter


//Debounce library needed
//Available at: https://github.com/wkoch/Debounce
#include <Debounce.h>

//Digital Pin 4 = Up Button
//Digital Pin 0 = Down Button
//Digital Pin 1 = brigtness

#define UP 4
#define DOWN 0
#define BRIGHT 1
#define BOOTBRIGHTNESS 255

//Debounce objects for each button
Debounce debouncerUp(UP);
Debounce debouncerDown(DOWN);

//Brightness from 0-255
int brightness = BOOTBRIGHTNESS;

//Button pressed lockout
bool lockout = false;

//Hold timer
unsigned int timer = 0;

//Increment/Decrement on button press per 100 millis
int increment = 5;


void setup() {

  //Setup PWM output
  pinMode(BRIGHT, OUTPUT);
  analogWrite(BRIGHT, 255);

  //Setup buttons
  pinMode(UP, INPUT_PULLUP);
  pinMode(DOWN, INPUT_PULLUP);
}

void lock() {
  //Check if button hasn't been pressed
  if (lockout == false) {
    //Start the timer
    timer = millis();
    //Set lockout
    lockout = true;
  }
  
  //Check if button has been held for more than a second
  if ((millis()-timer)>1000) {
    //increment/decrement by twice as much
    increment = 10;
  }
}

void out() {
  //Update the PWM pin, then wait
  analogWrite(BRIGHT, brightness);
  delay(100);
}

void loop() {
  //Get button value
  bool up = debouncerUp.read();
  bool down = debouncerDown.read();

  //If only one button is pressed
  if (up==LOW && down==HIGH) {
    //Check lockout/timer
    lock();

    //Change brightness value (up to 255)
    brightness +=increment;
    if (brightness >255) {
      brightness=255;
    }

    //Update output
    out();
    
  //If only one button is pressed
  } else if (down==LOW && up==HIGH) {
    //Check lockout/timer
    lock();

    //Change brightness value (down to 0)
    brightness -=increment;
    if (brightness <0) {
      brightness=0;
    }

    //Update output
    out();
    
  } else {
    //If no buttons are press, reset lockout, increment, and delay briefly
    lockout = false;
    increment = 5;
    delay(25);
  }
  
}




